@@ -10,6 +10,9 @@
 #define MAX_WIDTH 780
 #define MAX_HEIGH (MAX_WIDTH * 5398 / 8660)
 
+#define MAX_WIDTH_L 460
+#define MAX_HEIGH_L (MAX_WIDTH_L * 5398 / 8660)
+
 #define INTERNAL_WIDTH 400
 #define INTERNAL_HEIGH (INTERNAL_WIDTH * 5398 / 8660)
 
