@@ -41,6 +41,8 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 		QMainWindow(parent)
 {
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
+	if (!edit)
+		connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
 
 	isNew = target == NULL;
 
@@ -99,6 +101,7 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 
 	//setContextMenuPolicy(Qt::DefaultContextMenu);
 	setContextMenuPolicy(Qt::CustomContextMenu);
+	//centralWidget->setContextMenuPolicy(Qt::CustomContextMenu);
 
 	vboxlayout = new QVBoxLayout ();
 	vboxlayout->setSpacing(0);
@@ -133,7 +136,7 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 	if (edit) {
 		// type label
 		QLabel * typeLabel = new QLabel("Type", this);
-		//typeLabel->setContextMenuPolicy(Qt::NoContextMenu);
+
 		componentLayout->addWidget(typeLabel, 2, 1, 1, 2);
 
 		typeLineEdit = new QComboBox(this);
@@ -163,12 +166,11 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 
 	componentLayout = new QGridLayout ();
 
-	//setContextMenuPolicy(Qt::CustomContextMenu);
 	QObject::connect(this, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardMenu(const QPoint&)));
 
 	if (edit || target->getPicture() != NULL) {
 		imageLabel = new QLabel(this);
-		//imageLabel->setContextMenuPolicy(Qt::CustomContextMenu);
+
 		imageLabel->setBackgroundRole(QPalette::NoRole);
 		imageLabel->setContentsMargins(5, 2, 0, 2);
 		if (edit) {
@@ -189,7 +191,9 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 			imageLabel->setPixmap(QPixmap::fromImage (*currentImage));
 		}
 		
+		//imageLabel->setContextMenuPolicy(Qt::CustomContextMenu);
 		//QObject::connect(imageLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardFaceMenu(const QPoint&)));
+
 		if (edit) {
 			componentLayout->addWidget(imageLabel, 3, 1, 2, 3);
 		}
@@ -202,7 +206,7 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 
 	if (edit || target->getPictureBack() != NULL) {
 		imageBackLabel = new QLabel(this);
-		//imageBackLabel->setContextMenuPolicy(Qt::CustomContextMenu);
+
 		imageBackLabel->setBackgroundRole(QPalette::NoRole);
 		//imageBackLabel->setFocusPolicy(Qt::StrongFocus);
 		imageBackLabel->setContentsMargins(5, 2, 0, 2);
@@ -225,7 +229,9 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 			imageBackLabel->setPixmap(QPixmap::fromImage (*currentImageBack));
 		}
 
+		//imageBackLabel->setContextMenuPolicy(Qt::CustomContextMenu);
 		//QObject::connect(imageBackLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardBackMenu(const QPoint&)));
+
 		if (edit) {
 			componentLayout->addWidget(imageBackLabel, 3, 4, 2, 3);
 		}
@@ -254,7 +260,7 @@ void DetailWindow::modifyFields() {
 		createFieldDlg->setMinimumSize(size().width(),size().height()-100);
 		createFieldDlg->exec();
 
-		qDebug () << "NOW ";
+		//qDebug () << "NOW ";
 
 		showFields ();
 
@@ -580,9 +586,10 @@ void DetailWindow::loadImage (QString q, QImage& res) {
 }
 
 void DetailWindow::cardMenu(const QPoint & _p) {
-	QPoint p = this->mapFromGlobal(_p);
+	QPoint p = _p;//this->mapFromGlobal(_p);
 
 	QScrollBar* bar = entryScrollArea->verticalScrollBar();
+
 	if (bar)
 		p.setY(p.y() + bar->value());
 
@@ -690,36 +697,68 @@ void DetailWindow::mirrorBack () {
 		deleteBack = false;
 	}
 }
-void DetailWindow::cardBackMenu(const QPoint & pos) {
+//void DetailWindow::contextMenuEvent (QContextMenuEvent * event) {
+//	qDebug () << "NOW";
+//}
+//void DetailWindow::cardBackMenu(const QPoint & pos) {
+//
+//	//qDebug () << "MENU";
+//
+//	QMenu menu(this);
+//	if (edit) {
+//		menu.addAction("Edit", this, SLOT(cardBack()));
+//		menu.addAction("Mirror", this, SLOT(mirrorBack()));
+//		menu.addAction("Delete", this, SLOT(deleteCardBack()));
+//	}
+//	else {
+//		menu.addAction("Export", this, SLOT(exportCardBack()));
+//	}
+//	menu.exec(pos);
+//}
+//void DetailWindow::cardFaceMenu(const QPoint & pos) {
+//
+//	//qDebug () << "MENU";
+//
+//	QMenu menu(this);
+//	if (edit) {
+//		menu.addAction("Edit", this, SLOT(cardFace()));
+//		menu.addAction("Mirror", this, SLOT(mirrorFace()));
+//		menu.addAction("Delete", this, SLOT(deleteCardFace()));
+//	}
+//	else {
+//		menu.addAction("Export", this, SLOT(exportCardFace()));
+//	}
+//	menu.exec(pos);
+//}
 
-	//qDebug () << "MENU";
+void DetailWindow::orientationChanged(int o) {
+	//qDebug () << "CHAGNED";
 
-	QMenu menu(this);
-	if (edit) {
-		menu.addAction("Edit", this, SLOT(cardBack()));
-		menu.addAction("Mirror", this, SLOT(mirrorBack()));
-		menu.addAction("Delete", this, SLOT(deleteCardBack()));
+	if (!edit) {
+		QRect screenGeometry = QApplication::desktop()->screenGeometry();
+		if (screenGeometry.width() > screenGeometry.height()) {
+			if (imageLabel != NULL) {
+				imageLabel->setMaximumSize(MAX_WIDTH, MAX_HEIGH);
+				imageLabel->setMinimumSize(MAX_WIDTH, MAX_HEIGH);
+			}
+			if (imageBackLabel != NULL) {
+				imageBackLabel->setMaximumSize(MAX_WIDTH, MAX_HEIGH);
+				imageBackLabel->setMinimumSize(MAX_WIDTH, MAX_HEIGH);
+			}
+		}
+		else {
+			if (imageLabel != NULL) {
+				imageLabel->setMaximumSize(MAX_WIDTH_L, MAX_HEIGH_L);
+				imageLabel->setMinimumSize(MAX_WIDTH_L, MAX_HEIGH_L);
+			}
+			if (imageBackLabel != NULL) {
+				imageBackLabel->setMaximumSize(MAX_WIDTH_L, MAX_HEIGH_L);
+				imageBackLabel->setMinimumSize(MAX_WIDTH_L, MAX_HEIGH_L);
+			}
+		}
 	}
-	else {
-		menu.addAction("Export", this, SLOT(exportCardBack()));
-	}
-	menu.exec(pos);
 }
-void DetailWindow::cardFaceMenu(const QPoint & pos) {
 
-	//qDebug () << "MENU";
-
-	QMenu menu(this);
-	if (edit) {
-		menu.addAction("Edit", this, SLOT(cardFace()));
-		menu.addAction("Mirror", this, SLOT(mirrorFace()));
-		menu.addAction("Delete", this, SLOT(deleteCardFace()));
-	}
-	else {
-		menu.addAction("Export", this, SLOT(exportCardFace()));
-	}
-	menu.exec(pos);
-}
 void DetailWindow::deleteCardBack()
 {
 	QPixmap available(":/resources/empty_card_back.png");
