@@ -94,9 +94,9 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	connect(signalMapper, SIGNAL(mapped(const QString &)),
 	        this, SLOT(select(const QString &)));
 
-	componentLayout->addWidget(label, 4, 0, 1, 4);
+	componentLayout->addWidget(label, 4, 0, 1, 3);
 
-	QDialogButtonBox* dlgBtnBox = new QDialogButtonBox(this);
+	dlgBtnBox = new QDialogButtonBox(this);
 	dlgBtnBox->setOrientation(Qt::Vertical);
 
 	QPushButton * aboutButton = new QPushButton(QIcon(":/resources/about.png"), "About", this);
@@ -124,7 +124,7 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	dlgBtnBox->addButton(exitButton, QDialogButtonBox::ActionRole);
 
 	layout->addLayout(componentLayout);
-	layout->setAlignment(componentLayout, Qt::AlignVCenter);
+	layout->setAlignment(componentLayout, Qt::AlignVCenter | Qt::AlignHCenter);
 
 	layout->addWidget(dlgBtnBox);
 	layout->setAlignment(dlgBtnBox, Qt::AlignBottom);
@@ -137,6 +137,13 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 
 }
 
+void LoginDialog::orientationChanged(int o) {
+	QRect screenGeometry = QApplication::desktop()->screenGeometry();
+	if (screenGeometry.width() > screenGeometry.height())
+		dlgBtnBox->show ();
+	else
+		dlgBtnBox->hide ();
+}
 LoginDialog::~LoginDialog()
 {
 }
